# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'LedgerAzureadBasedServicePrincipalArgs',
    'LedgerAzureadBasedServicePrincipalArgsDict',
    'LedgerCertificateBasedSecurityPrincipalArgs',
    'LedgerCertificateBasedSecurityPrincipalArgsDict',
]

MYPY = False

if not MYPY:
    class LedgerAzureadBasedServicePrincipalArgsDict(TypedDict):
        ledger_role_name: pulumi.Input[str]
        """
        Specifies the Ledger Role to grant this AzureAD Service Principal. Possible values are `Administrator`, `Contributor` and `Reader`.
        """
        principal_id: pulumi.Input[str]
        """
        Specifies the Principal ID of the AzureAD Service Principal.
        """
        tenant_id: pulumi.Input[str]
        """
        Specifies the Tenant ID for this AzureAD Service Principal.
        """
elif False:
    LedgerAzureadBasedServicePrincipalArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class LedgerAzureadBasedServicePrincipalArgs:
    def __init__(__self__, *,
                 ledger_role_name: pulumi.Input[str],
                 principal_id: pulumi.Input[str],
                 tenant_id: pulumi.Input[str]):
        """
        :param pulumi.Input[str] ledger_role_name: Specifies the Ledger Role to grant this AzureAD Service Principal. Possible values are `Administrator`, `Contributor` and `Reader`.
        :param pulumi.Input[str] principal_id: Specifies the Principal ID of the AzureAD Service Principal.
        :param pulumi.Input[str] tenant_id: Specifies the Tenant ID for this AzureAD Service Principal.
        """
        pulumi.set(__self__, "ledger_role_name", ledger_role_name)
        pulumi.set(__self__, "principal_id", principal_id)
        pulumi.set(__self__, "tenant_id", tenant_id)

    @property
    @pulumi.getter(name="ledgerRoleName")
    def ledger_role_name(self) -> pulumi.Input[str]:
        """
        Specifies the Ledger Role to grant this AzureAD Service Principal. Possible values are `Administrator`, `Contributor` and `Reader`.
        """
        return pulumi.get(self, "ledger_role_name")

    @ledger_role_name.setter
    def ledger_role_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "ledger_role_name", value)

    @property
    @pulumi.getter(name="principalId")
    def principal_id(self) -> pulumi.Input[str]:
        """
        Specifies the Principal ID of the AzureAD Service Principal.
        """
        return pulumi.get(self, "principal_id")

    @principal_id.setter
    def principal_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "principal_id", value)

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> pulumi.Input[str]:
        """
        Specifies the Tenant ID for this AzureAD Service Principal.
        """
        return pulumi.get(self, "tenant_id")

    @tenant_id.setter
    def tenant_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "tenant_id", value)


if not MYPY:
    class LedgerCertificateBasedSecurityPrincipalArgsDict(TypedDict):
        ledger_role_name: pulumi.Input[str]
        """
        Specifies the Ledger Role to grant this Certificate Security Principal. Possible values are `Administrator`, `Contributor` and `Reader`.
        """
        pem_public_key: pulumi.Input[str]
        """
        The public key, in PEM format, of the certificate used by this identity to authenticate with the Confidential Ledger.
        """
elif False:
    LedgerCertificateBasedSecurityPrincipalArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class LedgerCertificateBasedSecurityPrincipalArgs:
    def __init__(__self__, *,
                 ledger_role_name: pulumi.Input[str],
                 pem_public_key: pulumi.Input[str]):
        """
        :param pulumi.Input[str] ledger_role_name: Specifies the Ledger Role to grant this Certificate Security Principal. Possible values are `Administrator`, `Contributor` and `Reader`.
        :param pulumi.Input[str] pem_public_key: The public key, in PEM format, of the certificate used by this identity to authenticate with the Confidential Ledger.
        """
        pulumi.set(__self__, "ledger_role_name", ledger_role_name)
        pulumi.set(__self__, "pem_public_key", pem_public_key)

    @property
    @pulumi.getter(name="ledgerRoleName")
    def ledger_role_name(self) -> pulumi.Input[str]:
        """
        Specifies the Ledger Role to grant this Certificate Security Principal. Possible values are `Administrator`, `Contributor` and `Reader`.
        """
        return pulumi.get(self, "ledger_role_name")

    @ledger_role_name.setter
    def ledger_role_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "ledger_role_name", value)

    @property
    @pulumi.getter(name="pemPublicKey")
    def pem_public_key(self) -> pulumi.Input[str]:
        """
        The public key, in PEM format, of the certificate used by this identity to authenticate with the Confidential Ledger.
        """
        return pulumi.get(self, "pem_public_key")

    @pem_public_key.setter
    def pem_public_key(self, value: pulumi.Input[str]):
        pulumi.set(self, "pem_public_key", value)


