# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

auxiliaryTenantIds: Optional[str]

clientCertificate: Optional[str]
"""
Base64 encoded PKCS#12 certificate bundle to use when authenticating as a Service Principal using a Client Certificate
"""

clientCertificatePassword: Optional[str]
"""
The password associated with the Client Certificate. For use when authenticating as a Service Principal using a Client
Certificate
"""

clientCertificatePath: Optional[str]
"""
The path to the Client Certificate associated with the Service Principal for use when authenticating as a Service
Principal using a Client Certificate.
"""

clientId: Optional[str]
"""
The Client ID which should be used.
"""

clientIdFilePath: Optional[str]
"""
The path to a file containing the Client ID which should be used.
"""

clientSecret: Optional[str]
"""
The Client Secret which should be used. For use When authenticating as a Service Principal using a Client Secret.
"""

clientSecretFilePath: Optional[str]
"""
The path to a file containing the Client Secret which should be used. For use When authenticating as a Service Principal
using a Client Secret.
"""

disableCorrelationRequestId: Optional[bool]
"""
This will disable the x-ms-correlation-request-id header.
"""

disableTerraformPartnerId: Optional[bool]

environment: str
"""
The Cloud Environment which should be used. Possible values are public, usgovernment, and china. Defaults to public. Not
used and should not be specified when `metadata_host` is specified.
"""

features: Optional[str]

location: Optional[str]

metadataHost: Optional[str]
"""
The Hostname which should be used for the Azure Metadata Service.
"""

msiEndpoint: Optional[str]
"""
The path to a custom endpoint for Managed Service Identity - in most circumstances this should be detected
automatically.
"""

oidcRequestToken: Optional[str]
"""
The bearer token for the request to the OIDC provider. For use when authenticating as a Service Principal using OpenID
Connect.
"""

oidcRequestUrl: Optional[str]
"""
The URL for the OIDC provider from which to request an ID token. For use when authenticating as a Service Principal
using OpenID Connect.
"""

oidcToken: Optional[str]
"""
The OIDC ID token for use when authenticating as a Service Principal using OpenID Connect.
"""

oidcTokenFilePath: Optional[str]
"""
The path to a file containing an OIDC ID token for use when authenticating as a Service Principal using OpenID Connect.
"""

partnerId: Optional[str]
"""
A GUID/UUID that is registered with Microsoft to facilitate partner resource usage attribution.
"""

resourceProviderRegistrations: Optional[str]
"""
The set of Resource Providers which should be automatically registered for the subscription.
"""

resourceProvidersToRegisters: Optional[str]
"""
A list of Resource Providers to explicitly register for the subscription, in addition to those specified by the
`resource_provider_registrations` property.
"""

skipProviderRegistration: bool
"""
Should the AzureRM Provider skip registering all of the Resource Providers that it supports, if they're not already
registered?
"""

storageUseAzuread: bool
"""
Should the AzureRM Provider use Azure AD Authentication when accessing the Storage Data Plane APIs?
"""

subscriptionId: str
"""
The Subscription ID which should be used.
"""

tenantId: Optional[str]
"""
The Tenant ID which should be used.
"""

useAksWorkloadIdentity: Optional[bool]
"""
Allow Azure AKS Workload Identity to be used for Authentication.
"""

useCli: Optional[bool]
"""
Allow Azure CLI to be used for Authentication.
"""

useMsi: Optional[bool]
"""
Allow Managed Service Identity to be used for Authentication.
"""

useOidc: Optional[bool]
"""
Allow OpenID Connect to be used for authentication
"""

