# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetNetworkManagerNetworkGroupResult',
    'AwaitableGetNetworkManagerNetworkGroupResult',
    'get_network_manager_network_group',
    'get_network_manager_network_group_output',
]

@pulumi.output_type
class GetNetworkManagerNetworkGroupResult:
    """
    A collection of values returned by getNetworkManagerNetworkGroup.
    """
    def __init__(__self__, description=None, id=None, name=None, network_manager_id=None):
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if network_manager_id and not isinstance(network_manager_id, str):
            raise TypeError("Expected argument 'network_manager_id' to be a str")
        pulumi.set(__self__, "network_manager_id", network_manager_id)

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        A description of the Network Manager Network Group.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="networkManagerId")
    def network_manager_id(self) -> str:
        return pulumi.get(self, "network_manager_id")


class AwaitableGetNetworkManagerNetworkGroupResult(GetNetworkManagerNetworkGroupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetNetworkManagerNetworkGroupResult(
            description=self.description,
            id=self.id,
            name=self.name,
            network_manager_id=self.network_manager_id)


def get_network_manager_network_group(name: Optional[str] = None,
                                      network_manager_id: Optional[str] = None,
                                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetNetworkManagerNetworkGroupResult:
    """
    Use this data source to access information about a Network Manager Network Group.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example_resource_group = azure.core.ResourceGroup("example",
        name="example-resources",
        location="West Europe")
    current = azure.core.get_subscription()
    example_network_manager = azure.network.NetworkManager("example",
        name="example-network-manager",
        location=example_resource_group.location,
        resource_group_name=example_resource_group.name,
        scope={
            "subscription_ids": [current.id],
        },
        scope_accesses=[
            "Connectivity",
            "SecurityAdmin",
        ],
        description="example network manager")
    example_network_manager_network_group = azure.network.NetworkManagerNetworkGroup("example",
        name="example-group",
        network_manager_id=example_network_manager.id)
    example = azure.network.get_network_manager_network_group_output(name=example_network_manager_network_group.name,
        network_manager_id=example_network_manager.id)
    ```


    :param str name: Specifies the name of the Network Manager Network Group.
    :param str network_manager_id: Specifies the ID of the Network Manager.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['networkManagerId'] = network_manager_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('azure:network/getNetworkManagerNetworkGroup:getNetworkManagerNetworkGroup', __args__, opts=opts, typ=GetNetworkManagerNetworkGroupResult).value

    return AwaitableGetNetworkManagerNetworkGroupResult(
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        network_manager_id=pulumi.get(__ret__, 'network_manager_id'))
def get_network_manager_network_group_output(name: Optional[pulumi.Input[str]] = None,
                                             network_manager_id: Optional[pulumi.Input[str]] = None,
                                             opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetNetworkManagerNetworkGroupResult]:
    """
    Use this data source to access information about a Network Manager Network Group.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example_resource_group = azure.core.ResourceGroup("example",
        name="example-resources",
        location="West Europe")
    current = azure.core.get_subscription()
    example_network_manager = azure.network.NetworkManager("example",
        name="example-network-manager",
        location=example_resource_group.location,
        resource_group_name=example_resource_group.name,
        scope={
            "subscription_ids": [current.id],
        },
        scope_accesses=[
            "Connectivity",
            "SecurityAdmin",
        ],
        description="example network manager")
    example_network_manager_network_group = azure.network.NetworkManagerNetworkGroup("example",
        name="example-group",
        network_manager_id=example_network_manager.id)
    example = azure.network.get_network_manager_network_group_output(name=example_network_manager_network_group.name,
        network_manager_id=example_network_manager.id)
    ```


    :param str name: Specifies the name of the Network Manager Network Group.
    :param str network_manager_id: Specifies the ID of the Network Manager.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['networkManagerId'] = network_manager_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('azure:network/getNetworkManagerNetworkGroup:getNetworkManagerNetworkGroup', __args__, opts=opts, typ=GetNetworkManagerNetworkGroupResult)
    return __ret__.apply(lambda __response__: GetNetworkManagerNetworkGroupResult(
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        network_manager_id=pulumi.get(__response__, 'network_manager_id')))
