# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'ConfigurationFeatureTargetingFilterArgs',
    'ConfigurationFeatureTargetingFilterArgsDict',
    'ConfigurationFeatureTargetingFilterGroupArgs',
    'ConfigurationFeatureTargetingFilterGroupArgsDict',
    'ConfigurationFeatureTimewindowFilterArgs',
    'ConfigurationFeatureTimewindowFilterArgsDict',
    'ConfigurationStoreEncryptionArgs',
    'ConfigurationStoreEncryptionArgsDict',
    'ConfigurationStoreIdentityArgs',
    'ConfigurationStoreIdentityArgsDict',
    'ConfigurationStorePrimaryReadKeyArgs',
    'ConfigurationStorePrimaryReadKeyArgsDict',
    'ConfigurationStorePrimaryWriteKeyArgs',
    'ConfigurationStorePrimaryWriteKeyArgsDict',
    'ConfigurationStoreReplicaArgs',
    'ConfigurationStoreReplicaArgsDict',
    'ConfigurationStoreSecondaryReadKeyArgs',
    'ConfigurationStoreSecondaryReadKeyArgsDict',
    'ConfigurationStoreSecondaryWriteKeyArgs',
    'ConfigurationStoreSecondaryWriteKeyArgsDict',
]

MYPY = False

if not MYPY:
    class ConfigurationFeatureTargetingFilterArgsDict(TypedDict):
        default_rollout_percentage: pulumi.Input[int]
        """
        A number representing the percentage of the entire user base.
        """
        groups: NotRequired[pulumi.Input[Sequence[pulumi.Input['ConfigurationFeatureTargetingFilterGroupArgsDict']]]]
        """
        One or more `groups` blocks as defined below.
        """
        users: NotRequired[pulumi.Input[Sequence[pulumi.Input[str]]]]
        """
        A list of users to target for this feature.
        """
elif False:
    ConfigurationFeatureTargetingFilterArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ConfigurationFeatureTargetingFilterArgs:
    def __init__(__self__, *,
                 default_rollout_percentage: pulumi.Input[int],
                 groups: Optional[pulumi.Input[Sequence[pulumi.Input['ConfigurationFeatureTargetingFilterGroupArgs']]]] = None,
                 users: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        :param pulumi.Input[int] default_rollout_percentage: A number representing the percentage of the entire user base.
        :param pulumi.Input[Sequence[pulumi.Input['ConfigurationFeatureTargetingFilterGroupArgs']]] groups: One or more `groups` blocks as defined below.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] users: A list of users to target for this feature.
        """
        pulumi.set(__self__, "default_rollout_percentage", default_rollout_percentage)
        if groups is not None:
            pulumi.set(__self__, "groups", groups)
        if users is not None:
            pulumi.set(__self__, "users", users)

    @property
    @pulumi.getter(name="defaultRolloutPercentage")
    def default_rollout_percentage(self) -> pulumi.Input[int]:
        """
        A number representing the percentage of the entire user base.
        """
        return pulumi.get(self, "default_rollout_percentage")

    @default_rollout_percentage.setter
    def default_rollout_percentage(self, value: pulumi.Input[int]):
        pulumi.set(self, "default_rollout_percentage", value)

    @property
    @pulumi.getter
    def groups(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ConfigurationFeatureTargetingFilterGroupArgs']]]]:
        """
        One or more `groups` blocks as defined below.
        """
        return pulumi.get(self, "groups")

    @groups.setter
    def groups(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ConfigurationFeatureTargetingFilterGroupArgs']]]]):
        pulumi.set(self, "groups", value)

    @property
    @pulumi.getter
    def users(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of users to target for this feature.
        """
        return pulumi.get(self, "users")

    @users.setter
    def users(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "users", value)


if not MYPY:
    class ConfigurationFeatureTargetingFilterGroupArgsDict(TypedDict):
        name: pulumi.Input[str]
        """
        The name of the group.
        """
        rollout_percentage: pulumi.Input[int]
        """
        Rollout percentage of the group.
        """
elif False:
    ConfigurationFeatureTargetingFilterGroupArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ConfigurationFeatureTargetingFilterGroupArgs:
    def __init__(__self__, *,
                 name: pulumi.Input[str],
                 rollout_percentage: pulumi.Input[int]):
        """
        :param pulumi.Input[str] name: The name of the group.
        :param pulumi.Input[int] rollout_percentage: Rollout percentage of the group.
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "rollout_percentage", rollout_percentage)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        """
        The name of the group.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="rolloutPercentage")
    def rollout_percentage(self) -> pulumi.Input[int]:
        """
        Rollout percentage of the group.
        """
        return pulumi.get(self, "rollout_percentage")

    @rollout_percentage.setter
    def rollout_percentage(self, value: pulumi.Input[int]):
        pulumi.set(self, "rollout_percentage", value)


if not MYPY:
    class ConfigurationFeatureTimewindowFilterArgsDict(TypedDict):
        end: NotRequired[pulumi.Input[str]]
        """
        The latest timestamp the feature is enabled. The timestamp must be in RFC3339 format.
        """
        start: NotRequired[pulumi.Input[str]]
        """
        The earliest timestamp the feature is enabled. The timestamp must be in RFC3339 format.
        """
elif False:
    ConfigurationFeatureTimewindowFilterArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ConfigurationFeatureTimewindowFilterArgs:
    def __init__(__self__, *,
                 end: Optional[pulumi.Input[str]] = None,
                 start: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] end: The latest timestamp the feature is enabled. The timestamp must be in RFC3339 format.
        :param pulumi.Input[str] start: The earliest timestamp the feature is enabled. The timestamp must be in RFC3339 format.
        """
        if end is not None:
            pulumi.set(__self__, "end", end)
        if start is not None:
            pulumi.set(__self__, "start", start)

    @property
    @pulumi.getter
    def end(self) -> Optional[pulumi.Input[str]]:
        """
        The latest timestamp the feature is enabled. The timestamp must be in RFC3339 format.
        """
        return pulumi.get(self, "end")

    @end.setter
    def end(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "end", value)

    @property
    @pulumi.getter
    def start(self) -> Optional[pulumi.Input[str]]:
        """
        The earliest timestamp the feature is enabled. The timestamp must be in RFC3339 format.
        """
        return pulumi.get(self, "start")

    @start.setter
    def start(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "start", value)


if not MYPY:
    class ConfigurationStoreEncryptionArgsDict(TypedDict):
        identity_client_id: NotRequired[pulumi.Input[str]]
        """
        Specifies the client id of the identity which will be used to access key vault.
        """
        key_vault_key_identifier: NotRequired[pulumi.Input[str]]
        """
        Specifies the URI of the key vault key used to encrypt data.
        """
elif False:
    ConfigurationStoreEncryptionArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ConfigurationStoreEncryptionArgs:
    def __init__(__self__, *,
                 identity_client_id: Optional[pulumi.Input[str]] = None,
                 key_vault_key_identifier: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] identity_client_id: Specifies the client id of the identity which will be used to access key vault.
        :param pulumi.Input[str] key_vault_key_identifier: Specifies the URI of the key vault key used to encrypt data.
        """
        if identity_client_id is not None:
            pulumi.set(__self__, "identity_client_id", identity_client_id)
        if key_vault_key_identifier is not None:
            pulumi.set(__self__, "key_vault_key_identifier", key_vault_key_identifier)

    @property
    @pulumi.getter(name="identityClientId")
    def identity_client_id(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the client id of the identity which will be used to access key vault.
        """
        return pulumi.get(self, "identity_client_id")

    @identity_client_id.setter
    def identity_client_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "identity_client_id", value)

    @property
    @pulumi.getter(name="keyVaultKeyIdentifier")
    def key_vault_key_identifier(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the URI of the key vault key used to encrypt data.
        """
        return pulumi.get(self, "key_vault_key_identifier")

    @key_vault_key_identifier.setter
    def key_vault_key_identifier(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "key_vault_key_identifier", value)


if not MYPY:
    class ConfigurationStoreIdentityArgsDict(TypedDict):
        type: pulumi.Input[str]
        """
        Specifies the type of Managed Service Identity that should be configured on this App Configuration. Possible values are `SystemAssigned`, `UserAssigned`, `SystemAssigned, UserAssigned` (to enable both).
        """
        identity_ids: NotRequired[pulumi.Input[Sequence[pulumi.Input[str]]]]
        """
        A list of User Assigned Managed Identity IDs to be assigned to this App Configuration.

        > **Note:** This is required when `type` is set to `UserAssigned` or `SystemAssigned, UserAssigned`.
        """
        principal_id: NotRequired[pulumi.Input[str]]
        """
        The Principal ID associated with this Managed Service Identity.
        """
        tenant_id: NotRequired[pulumi.Input[str]]
        """
        The Tenant ID associated with this Managed Service Identity.
        """
elif False:
    ConfigurationStoreIdentityArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ConfigurationStoreIdentityArgs:
    def __init__(__self__, *,
                 type: pulumi.Input[str],
                 identity_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 principal_id: Optional[pulumi.Input[str]] = None,
                 tenant_id: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] type: Specifies the type of Managed Service Identity that should be configured on this App Configuration. Possible values are `SystemAssigned`, `UserAssigned`, `SystemAssigned, UserAssigned` (to enable both).
        :param pulumi.Input[Sequence[pulumi.Input[str]]] identity_ids: A list of User Assigned Managed Identity IDs to be assigned to this App Configuration.
               
               > **Note:** This is required when `type` is set to `UserAssigned` or `SystemAssigned, UserAssigned`.
        :param pulumi.Input[str] principal_id: The Principal ID associated with this Managed Service Identity.
        :param pulumi.Input[str] tenant_id: The Tenant ID associated with this Managed Service Identity.
        """
        pulumi.set(__self__, "type", type)
        if identity_ids is not None:
            pulumi.set(__self__, "identity_ids", identity_ids)
        if principal_id is not None:
            pulumi.set(__self__, "principal_id", principal_id)
        if tenant_id is not None:
            pulumi.set(__self__, "tenant_id", tenant_id)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[str]:
        """
        Specifies the type of Managed Service Identity that should be configured on this App Configuration. Possible values are `SystemAssigned`, `UserAssigned`, `SystemAssigned, UserAssigned` (to enable both).
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="identityIds")
    def identity_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of User Assigned Managed Identity IDs to be assigned to this App Configuration.

        > **Note:** This is required when `type` is set to `UserAssigned` or `SystemAssigned, UserAssigned`.
        """
        return pulumi.get(self, "identity_ids")

    @identity_ids.setter
    def identity_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "identity_ids", value)

    @property
    @pulumi.getter(name="principalId")
    def principal_id(self) -> Optional[pulumi.Input[str]]:
        """
        The Principal ID associated with this Managed Service Identity.
        """
        return pulumi.get(self, "principal_id")

    @principal_id.setter
    def principal_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "principal_id", value)

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[pulumi.Input[str]]:
        """
        The Tenant ID associated with this Managed Service Identity.
        """
        return pulumi.get(self, "tenant_id")

    @tenant_id.setter
    def tenant_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tenant_id", value)


if not MYPY:
    class ConfigurationStorePrimaryReadKeyArgsDict(TypedDict):
        connection_string: NotRequired[pulumi.Input[str]]
        """
        The Connection String for this Access Key - comprising of the Endpoint, ID and Secret.
        """
        id: NotRequired[pulumi.Input[str]]
        """
        The ID of the Access Key.
        """
        secret: NotRequired[pulumi.Input[str]]
        """
        The Secret of the Access Key.
        """
elif False:
    ConfigurationStorePrimaryReadKeyArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ConfigurationStorePrimaryReadKeyArgs:
    def __init__(__self__, *,
                 connection_string: Optional[pulumi.Input[str]] = None,
                 id: Optional[pulumi.Input[str]] = None,
                 secret: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] connection_string: The Connection String for this Access Key - comprising of the Endpoint, ID and Secret.
        :param pulumi.Input[str] id: The ID of the Access Key.
        :param pulumi.Input[str] secret: The Secret of the Access Key.
        """
        if connection_string is not None:
            pulumi.set(__self__, "connection_string", connection_string)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if secret is not None:
            pulumi.set(__self__, "secret", secret)

    @property
    @pulumi.getter(name="connectionString")
    def connection_string(self) -> Optional[pulumi.Input[str]]:
        """
        The Connection String for this Access Key - comprising of the Endpoint, ID and Secret.
        """
        return pulumi.get(self, "connection_string")

    @connection_string.setter
    def connection_string(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "connection_string", value)

    @property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Access Key.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "id", value)

    @property
    @pulumi.getter
    def secret(self) -> Optional[pulumi.Input[str]]:
        """
        The Secret of the Access Key.
        """
        return pulumi.get(self, "secret")

    @secret.setter
    def secret(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "secret", value)


if not MYPY:
    class ConfigurationStorePrimaryWriteKeyArgsDict(TypedDict):
        connection_string: NotRequired[pulumi.Input[str]]
        """
        The Connection String for this Access Key - comprising of the Endpoint, ID and Secret.
        """
        id: NotRequired[pulumi.Input[str]]
        """
        The ID of the Access Key.
        """
        secret: NotRequired[pulumi.Input[str]]
        """
        The Secret of the Access Key.
        """
elif False:
    ConfigurationStorePrimaryWriteKeyArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ConfigurationStorePrimaryWriteKeyArgs:
    def __init__(__self__, *,
                 connection_string: Optional[pulumi.Input[str]] = None,
                 id: Optional[pulumi.Input[str]] = None,
                 secret: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] connection_string: The Connection String for this Access Key - comprising of the Endpoint, ID and Secret.
        :param pulumi.Input[str] id: The ID of the Access Key.
        :param pulumi.Input[str] secret: The Secret of the Access Key.
        """
        if connection_string is not None:
            pulumi.set(__self__, "connection_string", connection_string)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if secret is not None:
            pulumi.set(__self__, "secret", secret)

    @property
    @pulumi.getter(name="connectionString")
    def connection_string(self) -> Optional[pulumi.Input[str]]:
        """
        The Connection String for this Access Key - comprising of the Endpoint, ID and Secret.
        """
        return pulumi.get(self, "connection_string")

    @connection_string.setter
    def connection_string(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "connection_string", value)

    @property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Access Key.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "id", value)

    @property
    @pulumi.getter
    def secret(self) -> Optional[pulumi.Input[str]]:
        """
        The Secret of the Access Key.
        """
        return pulumi.get(self, "secret")

    @secret.setter
    def secret(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "secret", value)


if not MYPY:
    class ConfigurationStoreReplicaArgsDict(TypedDict):
        location: pulumi.Input[str]
        """
        Specifies the supported Azure location where the replica exists.
        """
        name: pulumi.Input[str]
        """
        Specifies the name of the replica.
        """
        endpoint: NotRequired[pulumi.Input[str]]
        """
        The URL of the App Configuration Replica.
        """
        id: NotRequired[pulumi.Input[str]]
        """
        The ID of the Access Key.
        """
elif False:
    ConfigurationStoreReplicaArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ConfigurationStoreReplicaArgs:
    def __init__(__self__, *,
                 location: pulumi.Input[str],
                 name: pulumi.Input[str],
                 endpoint: Optional[pulumi.Input[str]] = None,
                 id: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] location: Specifies the supported Azure location where the replica exists.
        :param pulumi.Input[str] name: Specifies the name of the replica.
        :param pulumi.Input[str] endpoint: The URL of the App Configuration Replica.
        :param pulumi.Input[str] id: The ID of the Access Key.
        """
        pulumi.set(__self__, "location", location)
        pulumi.set(__self__, "name", name)
        if endpoint is not None:
            pulumi.set(__self__, "endpoint", endpoint)
        if id is not None:
            pulumi.set(__self__, "id", id)

    @property
    @pulumi.getter
    def location(self) -> pulumi.Input[str]:
        """
        Specifies the supported Azure location where the replica exists.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: pulumi.Input[str]):
        pulumi.set(self, "location", value)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        """
        Specifies the name of the replica.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def endpoint(self) -> Optional[pulumi.Input[str]]:
        """
        The URL of the App Configuration Replica.
        """
        return pulumi.get(self, "endpoint")

    @endpoint.setter
    def endpoint(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "endpoint", value)

    @property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Access Key.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "id", value)


if not MYPY:
    class ConfigurationStoreSecondaryReadKeyArgsDict(TypedDict):
        connection_string: NotRequired[pulumi.Input[str]]
        """
        The Connection String for this Access Key - comprising of the Endpoint, ID and Secret.
        """
        id: NotRequired[pulumi.Input[str]]
        """
        The ID of the Access Key.
        """
        secret: NotRequired[pulumi.Input[str]]
        """
        The Secret of the Access Key.
        """
elif False:
    ConfigurationStoreSecondaryReadKeyArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ConfigurationStoreSecondaryReadKeyArgs:
    def __init__(__self__, *,
                 connection_string: Optional[pulumi.Input[str]] = None,
                 id: Optional[pulumi.Input[str]] = None,
                 secret: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] connection_string: The Connection String for this Access Key - comprising of the Endpoint, ID and Secret.
        :param pulumi.Input[str] id: The ID of the Access Key.
        :param pulumi.Input[str] secret: The Secret of the Access Key.
        """
        if connection_string is not None:
            pulumi.set(__self__, "connection_string", connection_string)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if secret is not None:
            pulumi.set(__self__, "secret", secret)

    @property
    @pulumi.getter(name="connectionString")
    def connection_string(self) -> Optional[pulumi.Input[str]]:
        """
        The Connection String for this Access Key - comprising of the Endpoint, ID and Secret.
        """
        return pulumi.get(self, "connection_string")

    @connection_string.setter
    def connection_string(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "connection_string", value)

    @property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Access Key.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "id", value)

    @property
    @pulumi.getter
    def secret(self) -> Optional[pulumi.Input[str]]:
        """
        The Secret of the Access Key.
        """
        return pulumi.get(self, "secret")

    @secret.setter
    def secret(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "secret", value)


if not MYPY:
    class ConfigurationStoreSecondaryWriteKeyArgsDict(TypedDict):
        connection_string: NotRequired[pulumi.Input[str]]
        """
        The Connection String for this Access Key - comprising of the Endpoint, ID and Secret.
        """
        id: NotRequired[pulumi.Input[str]]
        """
        The ID of the Access Key.
        """
        secret: NotRequired[pulumi.Input[str]]
        """
        The Secret of the Access Key.
        """
elif False:
    ConfigurationStoreSecondaryWriteKeyArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ConfigurationStoreSecondaryWriteKeyArgs:
    def __init__(__self__, *,
                 connection_string: Optional[pulumi.Input[str]] = None,
                 id: Optional[pulumi.Input[str]] = None,
                 secret: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] connection_string: The Connection String for this Access Key - comprising of the Endpoint, ID and Secret.
        :param pulumi.Input[str] id: The ID of the Access Key.
        :param pulumi.Input[str] secret: The Secret of the Access Key.
        """
        if connection_string is not None:
            pulumi.set(__self__, "connection_string", connection_string)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if secret is not None:
            pulumi.set(__self__, "secret", secret)

    @property
    @pulumi.getter(name="connectionString")
    def connection_string(self) -> Optional[pulumi.Input[str]]:
        """
        The Connection String for this Access Key - comprising of the Endpoint, ID and Secret.
        """
        return pulumi.get(self, "connection_string")

    @connection_string.setter
    def connection_string(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "connection_string", value)

    @property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Access Key.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "id", value)

    @property
    @pulumi.getter
    def secret(self) -> Optional[pulumi.Input[str]]:
        """
        The Secret of the Access Key.
        """
        return pulumi.get(self, "secret")

    @secret.setter
    def secret(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "secret", value)


