# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from .. import _utilities
import typing
# Export this package's modules as members:
from .a_record import *
from .aaaa_record import *
from .cname_record import *
from .get_a_record import *
from .get_aaaa_record import *
from .get_cname_record import *
from .get_dns_zone import *
from .get_mx_record import *
from .get_ptr_record import *
from .get_resolver import *
from .get_resolver_dns_forwarding_ruleset import *
from .get_resolver_forwarding_rule import *
from .get_resolver_inbound_endpoint import *
from .get_resolver_outbound_endpoint import *
from .get_resolver_virtual_network_link import *
from .get_soa_record import *
from .get_srv_record import *
from .get_txt_record import *
from .get_zone_virtual_network_link import *
from .link_service import *
from .mx_record import *
from .ptr_record import *
from .resolver import *
from .resolver_dns_forwarding_ruleset import *
from .resolver_forwarding_rule import *
from .resolver_inbound_endpoint import *
from .resolver_outbound_endpoint import *
from .resolver_virtual_network_link import *
from .srv_record import *
from .txt_record import *
from .zone import *
from .zone_virtual_network_link import *
from ._inputs import *
from . import outputs
