# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'MonitorIdentityArgs',
    'MonitorIdentityArgsDict',
    'MonitorPlanArgs',
    'MonitorPlanArgsDict',
    'MonitorUserArgs',
    'MonitorUserArgsDict',
    'TagRuleLogTagFilterArgs',
    'TagRuleLogTagFilterArgsDict',
    'TagRuleMetricTagFilterArgs',
    'TagRuleMetricTagFilterArgsDict',
]

MYPY = False

if not MYPY:
    class MonitorIdentityArgsDict(TypedDict):
        type: pulumi.Input[str]
        """
        Specifies the identity type of the Azure Native New Relic Monitor. The only possible value is `SystemAssigned`. Changing this forces a new Azure Native New Relic Monitor to be created.
        """
        principal_id: NotRequired[pulumi.Input[str]]
        """
        The Principal ID for the Service Principal associated with the Identity of this Azure Native New Relic Monitor.
        """
        tenant_id: NotRequired[pulumi.Input[str]]
        """
        The Tenant ID for the Service Principal associated with the Identity of this Azure Native New Relic Monitor.
        """
elif False:
    MonitorIdentityArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class MonitorIdentityArgs:
    def __init__(__self__, *,
                 type: pulumi.Input[str],
                 principal_id: Optional[pulumi.Input[str]] = None,
                 tenant_id: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] type: Specifies the identity type of the Azure Native New Relic Monitor. The only possible value is `SystemAssigned`. Changing this forces a new Azure Native New Relic Monitor to be created.
        :param pulumi.Input[str] principal_id: The Principal ID for the Service Principal associated with the Identity of this Azure Native New Relic Monitor.
        :param pulumi.Input[str] tenant_id: The Tenant ID for the Service Principal associated with the Identity of this Azure Native New Relic Monitor.
        """
        pulumi.set(__self__, "type", type)
        if principal_id is not None:
            pulumi.set(__self__, "principal_id", principal_id)
        if tenant_id is not None:
            pulumi.set(__self__, "tenant_id", tenant_id)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[str]:
        """
        Specifies the identity type of the Azure Native New Relic Monitor. The only possible value is `SystemAssigned`. Changing this forces a new Azure Native New Relic Monitor to be created.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="principalId")
    def principal_id(self) -> Optional[pulumi.Input[str]]:
        """
        The Principal ID for the Service Principal associated with the Identity of this Azure Native New Relic Monitor.
        """
        return pulumi.get(self, "principal_id")

    @principal_id.setter
    def principal_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "principal_id", value)

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[pulumi.Input[str]]:
        """
        The Tenant ID for the Service Principal associated with the Identity of this Azure Native New Relic Monitor.
        """
        return pulumi.get(self, "tenant_id")

    @tenant_id.setter
    def tenant_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tenant_id", value)


if not MYPY:
    class MonitorPlanArgsDict(TypedDict):
        effective_date: pulumi.Input[str]
        """
        Specifies the date when plan was applied. Changing this forces a new Azure Native New Relic Monitor to be created.
        """
        billing_cycle: NotRequired[pulumi.Input[str]]
        """
        Specifies the billing cycles. Possible values are `MONTHLY`, `WEEKLY` and `YEARLY`. Defaults to `MONTHLY`. Changing this forces a new Azure Native New Relic Monitor to be created.
        """
        plan_id: NotRequired[pulumi.Input[str]]
        """
        Specifies the plan id published by NewRelic. The only possible value is `newrelic-pay-as-you-go-free-live`. Defaults to `newrelic-pay-as-you-go-free-live`. Changing this forces a new Azure Native New Relic Monitor to be created.
        """
        usage_type: NotRequired[pulumi.Input[str]]
        """
        Specifies the usage type. Possible values are `COMMITTED` and `PAYG`. Defaults to `PAYG`. Changing this forces a new Azure Native New Relic Monitor to be created.
        """
elif False:
    MonitorPlanArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class MonitorPlanArgs:
    def __init__(__self__, *,
                 effective_date: pulumi.Input[str],
                 billing_cycle: Optional[pulumi.Input[str]] = None,
                 plan_id: Optional[pulumi.Input[str]] = None,
                 usage_type: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] effective_date: Specifies the date when plan was applied. Changing this forces a new Azure Native New Relic Monitor to be created.
        :param pulumi.Input[str] billing_cycle: Specifies the billing cycles. Possible values are `MONTHLY`, `WEEKLY` and `YEARLY`. Defaults to `MONTHLY`. Changing this forces a new Azure Native New Relic Monitor to be created.
        :param pulumi.Input[str] plan_id: Specifies the plan id published by NewRelic. The only possible value is `newrelic-pay-as-you-go-free-live`. Defaults to `newrelic-pay-as-you-go-free-live`. Changing this forces a new Azure Native New Relic Monitor to be created.
        :param pulumi.Input[str] usage_type: Specifies the usage type. Possible values are `COMMITTED` and `PAYG`. Defaults to `PAYG`. Changing this forces a new Azure Native New Relic Monitor to be created.
        """
        pulumi.set(__self__, "effective_date", effective_date)
        if billing_cycle is not None:
            pulumi.set(__self__, "billing_cycle", billing_cycle)
        if plan_id is not None:
            pulumi.set(__self__, "plan_id", plan_id)
        if usage_type is not None:
            pulumi.set(__self__, "usage_type", usage_type)

    @property
    @pulumi.getter(name="effectiveDate")
    def effective_date(self) -> pulumi.Input[str]:
        """
        Specifies the date when plan was applied. Changing this forces a new Azure Native New Relic Monitor to be created.
        """
        return pulumi.get(self, "effective_date")

    @effective_date.setter
    def effective_date(self, value: pulumi.Input[str]):
        pulumi.set(self, "effective_date", value)

    @property
    @pulumi.getter(name="billingCycle")
    def billing_cycle(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the billing cycles. Possible values are `MONTHLY`, `WEEKLY` and `YEARLY`. Defaults to `MONTHLY`. Changing this forces a new Azure Native New Relic Monitor to be created.
        """
        return pulumi.get(self, "billing_cycle")

    @billing_cycle.setter
    def billing_cycle(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "billing_cycle", value)

    @property
    @pulumi.getter(name="planId")
    def plan_id(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the plan id published by NewRelic. The only possible value is `newrelic-pay-as-you-go-free-live`. Defaults to `newrelic-pay-as-you-go-free-live`. Changing this forces a new Azure Native New Relic Monitor to be created.
        """
        return pulumi.get(self, "plan_id")

    @plan_id.setter
    def plan_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "plan_id", value)

    @property
    @pulumi.getter(name="usageType")
    def usage_type(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the usage type. Possible values are `COMMITTED` and `PAYG`. Defaults to `PAYG`. Changing this forces a new Azure Native New Relic Monitor to be created.
        """
        return pulumi.get(self, "usage_type")

    @usage_type.setter
    def usage_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "usage_type", value)


if not MYPY:
    class MonitorUserArgsDict(TypedDict):
        email: pulumi.Input[str]
        """
        Specifies the user Email. Changing this forces a new Azure Native New Relic Monitor to be created.
        """
        first_name: pulumi.Input[str]
        """
        Specifies the first name. Changing this forces a new Azure Native New Relic Monitor to be created.
        """
        last_name: pulumi.Input[str]
        """
        Specifies the last name. Changing this forces a new Azure Native New Relic Monitor to be created.
        """
        phone_number: pulumi.Input[str]
        """
        Specifies the contact phone number. Changing this forces a new Azure Native New Relic Monitor to be created.
        """
elif False:
    MonitorUserArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class MonitorUserArgs:
    def __init__(__self__, *,
                 email: pulumi.Input[str],
                 first_name: pulumi.Input[str],
                 last_name: pulumi.Input[str],
                 phone_number: pulumi.Input[str]):
        """
        :param pulumi.Input[str] email: Specifies the user Email. Changing this forces a new Azure Native New Relic Monitor to be created.
        :param pulumi.Input[str] first_name: Specifies the first name. Changing this forces a new Azure Native New Relic Monitor to be created.
        :param pulumi.Input[str] last_name: Specifies the last name. Changing this forces a new Azure Native New Relic Monitor to be created.
        :param pulumi.Input[str] phone_number: Specifies the contact phone number. Changing this forces a new Azure Native New Relic Monitor to be created.
        """
        pulumi.set(__self__, "email", email)
        pulumi.set(__self__, "first_name", first_name)
        pulumi.set(__self__, "last_name", last_name)
        pulumi.set(__self__, "phone_number", phone_number)

    @property
    @pulumi.getter
    def email(self) -> pulumi.Input[str]:
        """
        Specifies the user Email. Changing this forces a new Azure Native New Relic Monitor to be created.
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: pulumi.Input[str]):
        pulumi.set(self, "email", value)

    @property
    @pulumi.getter(name="firstName")
    def first_name(self) -> pulumi.Input[str]:
        """
        Specifies the first name. Changing this forces a new Azure Native New Relic Monitor to be created.
        """
        return pulumi.get(self, "first_name")

    @first_name.setter
    def first_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "first_name", value)

    @property
    @pulumi.getter(name="lastName")
    def last_name(self) -> pulumi.Input[str]:
        """
        Specifies the last name. Changing this forces a new Azure Native New Relic Monitor to be created.
        """
        return pulumi.get(self, "last_name")

    @last_name.setter
    def last_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "last_name", value)

    @property
    @pulumi.getter(name="phoneNumber")
    def phone_number(self) -> pulumi.Input[str]:
        """
        Specifies the contact phone number. Changing this forces a new Azure Native New Relic Monitor to be created.
        """
        return pulumi.get(self, "phone_number")

    @phone_number.setter
    def phone_number(self, value: pulumi.Input[str]):
        pulumi.set(self, "phone_number", value)


if not MYPY:
    class TagRuleLogTagFilterArgsDict(TypedDict):
        action: pulumi.Input[str]
        """
        Valid actions for a filtering tag. Possible values are `Exclude` and `Include`. Exclusion takes priority over inclusion.
        """
        name: pulumi.Input[str]
        """
        Specifies the name (also known as the key) of the tag.
        """
        value: pulumi.Input[str]
        """
        Specifies the value of the tag.
        """
elif False:
    TagRuleLogTagFilterArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class TagRuleLogTagFilterArgs:
    def __init__(__self__, *,
                 action: pulumi.Input[str],
                 name: pulumi.Input[str],
                 value: pulumi.Input[str]):
        """
        :param pulumi.Input[str] action: Valid actions for a filtering tag. Possible values are `Exclude` and `Include`. Exclusion takes priority over inclusion.
        :param pulumi.Input[str] name: Specifies the name (also known as the key) of the tag.
        :param pulumi.Input[str] value: Specifies the value of the tag.
        """
        pulumi.set(__self__, "action", action)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def action(self) -> pulumi.Input[str]:
        """
        Valid actions for a filtering tag. Possible values are `Exclude` and `Include`. Exclusion takes priority over inclusion.
        """
        return pulumi.get(self, "action")

    @action.setter
    def action(self, value: pulumi.Input[str]):
        pulumi.set(self, "action", value)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        """
        Specifies the name (also known as the key) of the tag.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def value(self) -> pulumi.Input[str]:
        """
        Specifies the value of the tag.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: pulumi.Input[str]):
        pulumi.set(self, "value", value)


if not MYPY:
    class TagRuleMetricTagFilterArgsDict(TypedDict):
        action: pulumi.Input[str]
        """
        Valid actions for a filtering tag. Possible values are `Exclude` and `Include`. Exclusion takes priority over inclusion.
        """
        name: pulumi.Input[str]
        """
        Specifies the name (also known as the key) of the tag.
        """
        value: pulumi.Input[str]
        """
        Specifies the value of the tag.
        """
elif False:
    TagRuleMetricTagFilterArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class TagRuleMetricTagFilterArgs:
    def __init__(__self__, *,
                 action: pulumi.Input[str],
                 name: pulumi.Input[str],
                 value: pulumi.Input[str]):
        """
        :param pulumi.Input[str] action: Valid actions for a filtering tag. Possible values are `Exclude` and `Include`. Exclusion takes priority over inclusion.
        :param pulumi.Input[str] name: Specifies the name (also known as the key) of the tag.
        :param pulumi.Input[str] value: Specifies the value of the tag.
        """
        pulumi.set(__self__, "action", action)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def action(self) -> pulumi.Input[str]:
        """
        Valid actions for a filtering tag. Possible values are `Exclude` and `Include`. Exclusion takes priority over inclusion.
        """
        return pulumi.get(self, "action")

    @action.setter
    def action(self, value: pulumi.Input[str]):
        pulumi.set(self, "action", value)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        """
        Specifies the name (also known as the key) of the tag.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def value(self) -> pulumi.Input[str]:
        """
        Specifies the value of the tag.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: pulumi.Input[str]):
        pulumi.set(self, "value", value)


