# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetMpaAccountScopeResult',
    'AwaitableGetMpaAccountScopeResult',
    'get_mpa_account_scope',
    'get_mpa_account_scope_output',
]

@pulumi.output_type
class GetMpaAccountScopeResult:
    """
    A collection of values returned by getMpaAccountScope.
    """
    def __init__(__self__, billing_account_name=None, customer_name=None, id=None):
        if billing_account_name and not isinstance(billing_account_name, str):
            raise TypeError("Expected argument 'billing_account_name' to be a str")
        pulumi.set(__self__, "billing_account_name", billing_account_name)
        if customer_name and not isinstance(customer_name, str):
            raise TypeError("Expected argument 'customer_name' to be a str")
        pulumi.set(__self__, "customer_name", customer_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)

    @property
    @pulumi.getter(name="billingAccountName")
    def billing_account_name(self) -> str:
        return pulumi.get(self, "billing_account_name")

    @property
    @pulumi.getter(name="customerName")
    def customer_name(self) -> str:
        return pulumi.get(self, "customer_name")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")


class AwaitableGetMpaAccountScopeResult(GetMpaAccountScopeResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetMpaAccountScopeResult(
            billing_account_name=self.billing_account_name,
            customer_name=self.customer_name,
            id=self.id)


def get_mpa_account_scope(billing_account_name: Optional[str] = None,
                          customer_name: Optional[str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetMpaAccountScopeResult:
    """
    Use this data source to access an ID for your MPA Account billing scope.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.billing.get_mpa_account_scope(billing_account_name="e879cf0f-2b4d-5431-109a-f72fc9868693:024cabf4-7321-4cf9-be59-df0c77ca51de_2019-05-31",
        customer_name="2281f543-7321-4cf9-1e23-edb4Oc31a31c")
    pulumi.export("id", example.id)
    ```


    :param str billing_account_name: The Billing Account Name of the MPA account.
    :param str customer_name: The Customer Name in the above Billing Account.
    """
    __args__ = dict()
    __args__['billingAccountName'] = billing_account_name
    __args__['customerName'] = customer_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('azure:billing/getMpaAccountScope:getMpaAccountScope', __args__, opts=opts, typ=GetMpaAccountScopeResult).value

    return AwaitableGetMpaAccountScopeResult(
        billing_account_name=pulumi.get(__ret__, 'billing_account_name'),
        customer_name=pulumi.get(__ret__, 'customer_name'),
        id=pulumi.get(__ret__, 'id'))
def get_mpa_account_scope_output(billing_account_name: Optional[pulumi.Input[str]] = None,
                                 customer_name: Optional[pulumi.Input[str]] = None,
                                 opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetMpaAccountScopeResult]:
    """
    Use this data source to access an ID for your MPA Account billing scope.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.billing.get_mpa_account_scope(billing_account_name="e879cf0f-2b4d-5431-109a-f72fc9868693:024cabf4-7321-4cf9-be59-df0c77ca51de_2019-05-31",
        customer_name="2281f543-7321-4cf9-1e23-edb4Oc31a31c")
    pulumi.export("id", example.id)
    ```


    :param str billing_account_name: The Billing Account Name of the MPA account.
    :param str customer_name: The Customer Name in the above Billing Account.
    """
    __args__ = dict()
    __args__['billingAccountName'] = billing_account_name
    __args__['customerName'] = customer_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('azure:billing/getMpaAccountScope:getMpaAccountScope', __args__, opts=opts, typ=GetMpaAccountScopeResult)
    return __ret__.apply(lambda __response__: GetMpaAccountScopeResult(
        billing_account_name=pulumi.get(__response__, 'billing_account_name'),
        customer_name=pulumi.get(__response__, 'customer_name'),
        id=pulumi.get(__response__, 'id')))
