# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetAdbsCharacterSetsResult',
    'AwaitableGetAdbsCharacterSetsResult',
    'get_adbs_character_sets',
    'get_adbs_character_sets_output',
]

@pulumi.output_type
class GetAdbsCharacterSetsResult:
    """
    A collection of values returned by getAdbsCharacterSets.
    """
    def __init__(__self__, character_sets=None, id=None, location=None):
        if character_sets and not isinstance(character_sets, list):
            raise TypeError("Expected argument 'character_sets' to be a list")
        pulumi.set(__self__, "character_sets", character_sets)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if location and not isinstance(location, str):
            raise TypeError("Expected argument 'location' to be a str")
        pulumi.set(__self__, "location", location)

    @property
    @pulumi.getter(name="characterSets")
    def character_sets(self) -> Sequence['outputs.GetAdbsCharacterSetsCharacterSetResult']:
        """
        A `character_sets` block as defined below.
        """
        return pulumi.get(self, "character_sets")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def location(self) -> str:
        return pulumi.get(self, "location")


class AwaitableGetAdbsCharacterSetsResult(GetAdbsCharacterSetsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAdbsCharacterSetsResult(
            character_sets=self.character_sets,
            id=self.id,
            location=self.location)


def get_adbs_character_sets(location: Optional[str] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAdbsCharacterSetsResult:
    """
    Gets a list of supported character sets.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.oracle.get_adbs_character_sets(location="West Europe")
    pulumi.export("example", example)
    ```


    :param str location: The Azure Region to query for the character sets in.
    """
    __args__ = dict()
    __args__['location'] = location
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('azure:oracle/getAdbsCharacterSets:getAdbsCharacterSets', __args__, opts=opts, typ=GetAdbsCharacterSetsResult).value

    return AwaitableGetAdbsCharacterSetsResult(
        character_sets=pulumi.get(__ret__, 'character_sets'),
        id=pulumi.get(__ret__, 'id'),
        location=pulumi.get(__ret__, 'location'))
def get_adbs_character_sets_output(location: Optional[pulumi.Input[str]] = None,
                                   opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAdbsCharacterSetsResult]:
    """
    Gets a list of supported character sets.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.oracle.get_adbs_character_sets(location="West Europe")
    pulumi.export("example", example)
    ```


    :param str location: The Azure Region to query for the character sets in.
    """
    __args__ = dict()
    __args__['location'] = location
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('azure:oracle/getAdbsCharacterSets:getAdbsCharacterSets', __args__, opts=opts, typ=GetAdbsCharacterSetsResult)
    return __ret__.apply(lambda __response__: GetAdbsCharacterSetsResult(
        character_sets=pulumi.get(__response__, 'character_sets'),
        id=pulumi.get(__response__, 'id'),
        location=pulumi.get(__response__, 'location')))
